# Python Library for IoT

This is an ongoing project to allow the creation of IoT based systems and services.
Currently we are focusing on IoT Core from AWS, but we expect to add more providers in the future.

### About Us
Ayllu Academy is a Descentralized Education platform that is currently build on-top of the Cardano ecosystem.